% This function checks if the DMM has an error in its error queue.
% If yes, then the errors are read out of the queue until there is no 
% error and an exception is thrown. If no, the function returns.

% The command sent to the instrument is "SYSTEM:ERROR". If the returned string
% from the DMM contains "No error" the error queue is empty. If if does not
% contain "No error", continue to send "SYSTEM:ERROR" and read the responses 
% until "No error" is received. All the errors then are reported in the exception 
% message.

function CheckDMMError(myDmm)

    errorString = query(myDmm,'SYSTEM:ERROR?');             % Query DMM for errors
    noError = strfind(errorString,'No error');              % Search for "No error"
    
    if ~isempty(noError)
        return;                                             % "No error" found, so return
    else
        % There is an error: read out all errors and return them in an exception
        allErrors = errorString;        
        while isempty(noError)            
            errorString = query(myDmm,'SYSTEM:ERROR?');     % Query DMM for errors
            noError = strfind(errorString,'No error');      % Search for "No error"
            if isempty(noError)
                allErrors = strcat(allErrors, '\n', errorString);
            end
        end
        errorMessage = strcat('Exception: Encountered system error(s):\n', allErrors);
        errorException = MException('ResultChk:BadInput', errorMessage);
        throw(errorException);
    end

end
